import { useShallow } from 'zustand/shallow';
import { getCurrentContent, useMenuStore, postContent, chain } from './store/menu';
import { useEffect, useRef, useState } from 'react';
import { checkText } from './modules/get-content-type';
import { TextEditor } from './editor/text/TextEditor';
import { useEditStore } from './store/edit';
export const Content: React.FC = () => {
  const { currentPath } = useMenuStore(
    useShallow((state) => ({
      currentPath: state.currentPath,
    })),
  );
  const [content, setContent] = useState<string | null>(null);
  const { type, setType } = useEditStore(
    useShallow((state) => ({
      type: state.type,
      setType: state.setType,
    })),
  );
  useEffect(() => {
    const fetchContent = async () => {
      if (currentPath) {
        const isText = checkText(currentPath);
        if (!isText.isText) {
          setContent('This file type is not supported for viewing.');
          setType('');
          return;
        }
        setContent('Loading content...');
        const content = await getCurrentContent(currentPath);
        setContent(content || '');
        setType('text');
      }
    };
    fetchContent();
  }, [currentPath]);

  return (
    <div className='h-full w-full overflow-y-auto scrollbar px-2'>
      <div className='flex flex-col w-full h-full relative'>
        <div className='w-full h-full relative'>{type === 'text' && <TextEditor filepath={currentPath!} content={content!} chain={chain} />}</div>
      </div>
    </div>
  );
};
